@@ -209,7 +209,6 @@ our %Modules = (
     'Compress::Raw::Bzip2' => {
         'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.206.tar.gz',
         'SYNCINFO'     => 'yorton on Tue Jul 25 20:45:42 2023',
-        'SYNCINFO'     => 'jkeenan on Wed Jul 19 09:49:28 2023',
         'FILES'        => q[cpan/Compress-Raw-Bzip2],
         'EXCLUDED'     => [
             qr{^t/Test/},
@@ -223,7 +222,6 @@ our %Modules = (
     'Compress::Raw::Zlib' => {
         'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.206.tar.gz',
         'SYNCINFO'     => 'yorton on Tue Jul 25 20:37:04 2023',
-        'SYNCINFO'     => 'jkeenan on Wed Jul 19 09:58:08 2023',
         'FILES'    => q[cpan/Compress-Raw-Zlib],
         'EXCLUDED' => [
             qr{^examples/},
@@ -403,7 +401,8 @@ our %Modules = (
     },
 
     'Encode' => {
-        'DISTRIBUTION' => 'DANKOGAI/Encode-3.19.tar.gz',
+        'DISTRIBUTION' => 'DANKOGAI/Encode-3.20.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Fri Nov 10 15:12:07 2023',
         'FILES'        => q[cpan/Encode],
         'EXCLUDED'     => [
             qw( t/whatwg-aliases.json
@@ -611,7 +610,8 @@ our %Modules = (
     },
 
     'Getopt::Long' => {
-        'DISTRIBUTION' => 'JV/Getopt-Long-2.54.tar.gz',
+        'DISTRIBUTION' => 'JV/Getopt-Long-2.57.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sat Nov 11 13:09:21 2023',
         'FILES'        => q[cpan/Getopt-Long],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -757,7 +757,8 @@ our %Modules = (
     },
 
     'Math::BigInt' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-1.999839.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-2.001000.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Tue Nov 14 17:22:07 2023',
         'FILES'        => q[cpan/Math-BigInt],
         'EXCLUDED'     => [
             qr{^xt/},
@@ -769,7 +770,8 @@ our %Modules = (
     },
 
     'Math::BigInt::FastCalc' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-FastCalc-0.5014.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-FastCalc-0.5015.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sun Sep 24 08:29:56 2023',
         'FILES'        => q[cpan/Math-BigInt-FastCalc],
         'EXCLUDED'     => [
             qr{^inc/},
@@ -791,20 +793,6 @@ our %Modules = (
         ],
     },
 
-    'Math::BigRat' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigRat-0.2624.tar.gz',
-        'FILES'        => q[cpan/Math-BigRat],
-        'EXCLUDED'     => [
-            qr{^xt/},
-            qr{^math-bigrat-pod.diff},
-            qr{^t/author-},
-            qr{^t/release-},
-            qw( t/00sig.t
-                t/01load.t
-                ),
-        ],
-    },
-
     'Math::Complex' => {
         'DISTRIBUTION' => 'ZEFRAM/Math-Complex-1.59.tar.gz',
         'FILES'        => q[dist/Math-Complex],
@@ -835,7 +823,7 @@ our %Modules = (
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20230820.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20230920.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -1083,15 +1071,23 @@ our %Modules = (
         'EXCLUDED'     => [qr{^t/release-.*\.t}],
     },
 
+    'Term::Table' => {
+        'DISTRIBUTION' => 'EXODIST/Term-Table-0.018.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Wed Nov  1 19:16:24 2023',
+        'FILES'        => q[cpan/Term-Table],
+        'EXCLUDED'     => [
+            qw( appveyor.yml ),
+        ],
+    },
+
     'Test' => {
         'DISTRIBUTION' => 'JESSE/Test-1.26.tar.gz',
         'FILES'        => q[dist/Test],
     },
 
     'Test::Harness' => {
-        'DISTRIBUTION' => 'LEONT/Test-Harness-3.47.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Wed Aug 16 18:28:09 2023',
-        'SYNCINFO'     => 'jkeenan on Sat Aug 12 17:05:02 2023',
+        'DISTRIBUTION' => 'LEONT/Test-Harness-3.48.tar.gz',
+        'SYNCINFO'     => 'gknop on Sat Oct 21 15:01:02 2023',
         'FILES'        => q[cpan/Test-Harness],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1120,6 +1116,20 @@ our %Modules = (
         ],
     },
 
+    'Test2::Suite' => {
+        'DISTRIBUTION' => 'EXODIST/Test2-Suite-0.000159.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Wed Nov  1 20:18:33 2023',
+        'FILES'        => q[cpan/Test2-Suite],
+        'EXCLUDED'     => [
+            qw( appveyor.yml
+                perltidyrc
+                t/00-report.t ),
+
+            # https://github.com/Test-More/Test2-Suite/issues/208
+            't/acceptance/Workflow-Acceptance.t',
+        ],
+    },
+
     'Text::Abbrev' => {
         'DISTRIBUTION' => 'FLORA/Text-Abbrev-1.02.tar.gz',
         'FILES'        => q[dist/Text-Abbrev],
@@ -1276,7 +1286,8 @@ our %Modules = (
     },
 
     'version' => {
-        'DISTRIBUTION' => 'LEONT/version-0.9929.tar.gz',
+        'DISTRIBUTION' => 'LEONT/version-0.9930.tar.gz',
+        'SYNCINFO'     => 'LeoNerd on Mon Sep 18 21:49:09 2023',
         'FILES'        => q[cpan/version vutil.c vutil.h vxs.inc],
         'EXCLUDED' => [
             qr{^vutil/lib/},
