@@ -28,15 +28,7 @@ struct TM64 {
 #endif
 
 #ifdef HAS_TM_TM_ZONE
-/* If glibc is defined or we are on QNX, use const.
- * Otherwise, if we are on android, use const but
- * not with g++.
- */
-#  if defined(__GLIBC__) || (defined(__ANDROID__) && !defined(__cplusplus)) \
-    || defined(__QNX__) || defined(__CYGWIN__)
-        const
-#  endif
-        char    *tm_zone;
+        const char *tm_zone;
 #endif
 };
 
